heurekaFeed2df: Customizable XML parser for product feeds.

Description Usage Arguments Details Examples

Description

heurekaFeed2df(doc) create a new datafraame containing the flat structure of the Heureka product feed. It skips problematics tags.

Usage

1
2
heurekaFeed2df(doc, xpath = "//SHOPITEM", isXML = TRUE, usewhich = TRUE,
  verbose = TRUE, skipTags = c("PARAM", "DELIVERY"))

Arguments

doc

XML parsed document or string or file

xpath

the xpath to shopitem in the feed

isXML

indicated if doc is parsed XML.

usewhich

is experimental. I looks like function works faster when set to true

verbose

sets debug messages on

skipTags

is a collection of tags which will not be processed. Typically multiplve values in PARAM and DELIVERY

Details

This is a XML parser optimised for Heureka feed. It can replaces XML::xmlTodataframe in all cases when this function fails for some reason. Function allow you to see debug messages and parametrize it's behavior.

Examples

1
2
3
library(XML)
doc <- xmlParse("http://my.eshop.cz/heureka.xml")
df <- heurekaFeed2df(doc)

etnetera-activate/WATAtools documentation built on May 16, 2019, 9:07 a.m.